Module: ActionView::Helpers::FormOptionsHelper
- Includes:
- TextHelper
- Included in:
- ActionView::Helpers, Tags::Base
- Defined in:
- lib/action_view/helpers/form_options_helper.rb
Overview
Provides a number of methods for turning different kinds of containers into a set of option tags.
The collection_select, select and time_zone_select methods take an options parameter, a hash:
-
:include_blank - set to true or a prompt string if the first option element of the select element is a blank. Useful if there is not a default value required for the select element.
select("post", "category", Post::CATEGORIES, {include_blank: true})could become:
Another common case is a select tag for a belongs_to-associated object.
Example with @post.person_id => 2:
select("post", "person_id", Person.all.collect {|p| [ p.name, p.id ] }, {include_blank: 'None'})could become:
-
:prompt - set to true or a prompt string. When the select element doesn't have a value yet, this prepends an option with a generic prompt -- "Please select" -- or the given prompt string.
select("post", "person_id", Person.all.collect {|p| [ p.name, p.id ] }, {prompt: 'Select Person'})could become:
-
:index - like the other form helpers,
selectcan accept an :index option to manually set the ID used in the resulting output. Unlike other helpers,selectexpects this option to be in thehtml_optionsparameter.select("album[]", "genre", %w[rap rock country], {}, { index: nil })becomes:
-
:disabled - can be a single value or an array of values that will be disabled options in the final output.
select("post", "category", Post::CATEGORIES, {disabled: 'restricted'})could become:
When used with the collection_select helper, :disabled can also be a Proc that identifies those options that should be disabled.
collection_select(:post, :category_id, Category.all, :id, :name, {disabled: lambda{|category| category.archived? }})If the categories "2008 stuff" and "Christmas" return true when the method archived? is called, this would return:
Constant Summary
Constants included from TagHelper
TagHelper::BOOLEAN_ATTRIBUTES, TagHelper::PRE_CONTENT_STRINGS, TagHelper::TAG_PREFIXES
Instance Method Summary collapse
-
#collection_check_boxes(object, method, collection, value_method, text_method, options = {}, html_options = {}, &block) ⇒ Object
Returns check box tags for the collection of existing return values of
methodfor +object+'s class. -
#collection_radio_buttons(object, method, collection, value_method, text_method, options = {}, html_options = {}, &block) ⇒ Object
Returns radio button tags for the collection of existing return values of
methodfor +object+'s class. -
#collection_select(object, method, collection, value_method, text_method, options = {}, html_options = {}) ⇒ Object
Returns and tags for the collection of existing return values of
methodfor +object+'s class. -
#grouped_collection_select(object, method, collection, group_method, group_label_method, option_key_method, option_value_method, options = {}, html_options = {}) ⇒ Object
Returns , and tags for the collection of existing return values of
methodfor +object+'s class. -
#grouped_options_for_select(grouped_options, selected_key = nil, options = {}) ⇒ Object
Returns a string of tags, like options_for_select, but wraps them with tags:.
-
#option_groups_from_collection_for_select(collection, group_method, group_label_method, option_key_method, option_value_method, selected_key = nil) ⇒ Object
Returns a string of tags, like options_from_collection_for_select, but groups them by tags based on the object relationships of the arguments.
-
#options_for_select(container, selected = nil) ⇒ Object
Accepts a container (hash, array, enumerable, your type) and returns a string of option tags.
-
#options_from_collection_for_select(collection, value_method, text_method, selected = nil) ⇒ Object
Returns a string of option tags that have been compiled by iterating over the
collectionand assigning the result of a call to thevalue_methodas the option value and thetext_methodas the option text. -
#select(object, method, choices = nil, options = {}, html_options = {}, &block) ⇒ Object
Create a select tag and a series of contained option tags for the provided object and method.
-
#time_zone_options_for_select(selected = nil, priority_zones = nil, model = ::ActiveSupport::TimeZone) ⇒ Object
Returns a string of option tags for pretty much any time zone in the world.
-
#time_zone_select(object, method, priority_zones = nil, options = {}, html_options = {}) ⇒ Object
Returns select and option tags for the given object and method, using #time_zone_options_for_select to generate the list of option tags.
Methods included from TextHelper
#concat, #current_cycle, #cycle, #excerpt, #highlight, #pluralize, #reset_cycle, #safe_concat, #simple_format, #truncate, #word_wrap
Methods included from OutputSafetyHelper
Methods included from TagHelper
#cdata_section, #content_tag, #escape_once, #tag
Methods included from CaptureHelper
#capture, #content_for, #content_for?, #provide, #with_output_buffer
Methods included from SanitizeHelper
#sanitize, #sanitize_css, #strip_links, #strip_tags
Instance Method Details
#collection_check_boxes(object, method, collection, value_method, text_method, options = {}, html_options = {}, &block) ⇒ Object
Returns check box tags for the collection of existing return values of
method for +object+'s class. The value returned from calling method
on the instance object will be selected. If calling method returns
nil, no selection is made.
The :value_method and :text_method parameters are
methods to be called on each member of collection. The return values
are used as the value attribute and contents of each check box tag,
respectively. They can also be any object that responds to call, such
as a proc, that will be called for each member of the collection to
retrieve the value/text.
Example object structure for use with this method: class Post < ActiveRecord::Base has_and_belongs_to_many :authors end class Author < ActiveRecord::Base has_and_belongs_to_many :posts def name_with_initial "#ActionView::Helpers::FormOptionsHelper.first_namefirst_name.first. #last_name" end end
Sample usage (selecting the associated Author for an instance of Post, @post): collection_check_boxes(:post, :author_ids, Author.all, :id, :name_with_initial)
If @post.author_ids is already [1], this would return:
It is also possible to customize the way the elements will be shown by giving a block to the method: collection_check_boxes(:post, :author_ids, Author.all, :id, :name_with_initial) do |b| b.label { b.check_box } end
The argument passed to the block is a special kind of builder for this collection, which has the ability to generate the label and check box for the current item in the collection, with proper text and value. Using it, you can change the label and check box display order or even use the label as wrapper, as in the example above.
The builder methods label and check_box also accept extra HTML options: collection_check_boxes(:post, :author_ids, Author.all, :id, :name_with_initial) do |b| b.label(class: "check_box") { b.check_box(class: "check_box") } end
There are also three special methods available: object, text and value, which are the current item being rendered, its text and value methods, respectively. You can use them like this: collection_check_boxes(:post, :author_ids, Author.all, :id, :name_with_initial) do |b| b.label(:"data-value" => b.value) { b.check_box + b.text } end
710 711 712 |
# File 'lib/action_view/helpers/form_options_helper.rb', line 710 def collection_check_boxes(object, method, collection, value_method, text_method, = {}, = {}, &block) Tags::CollectionCheckBoxes.new(object, method, self, collection, value_method, text_method, , ).render(&block) end |
#collection_radio_buttons(object, method, collection, value_method, text_method, options = {}, html_options = {}, &block) ⇒ Object
Returns radio button tags for the collection of existing return values
of method for +object+'s class. The value returned from calling
method on the instance object will be selected. If calling method
returns nil, no selection is made.
The :value_method and :text_method parameters are
methods to be called on each member of collection. The return values
are used as the value attribute and contents of each radio button tag,
respectively. They can also be any object that responds to call, such
as a proc, that will be called for each member of the collection to
retrieve the value/text.
Example object structure for use with this method: class Post < ActiveRecord::Base belongs_to :author end class Author < ActiveRecord::Base has_many :posts def name_with_initial "#ActionView::Helpers::FormOptionsHelper.first_namefirst_name.first. #last_name" end end
Sample usage (selecting the associated Author for an instance of Post, @post): collection_radio_buttons(:post, :author_id, Author.all, :id, :name_with_initial)
If @post.author_id is already 1, this would return:
It is also possible to customize the way the elements will be shown by giving a block to the method: collection_radio_buttons(:post, :author_id, Author.all, :id, :name_with_initial) do |b| b.label { b.radio_button } end
The argument passed to the block is a special kind of builder for this collection, which has the ability to generate the label and radio button for the current item in the collection, with proper text and value. Using it, you can change the label and radio button display order or even use the label as wrapper, as in the example above.
The builder methods label and radio_button also accept extra HTML options: collection_radio_buttons(:post, :author_id, Author.all, :id, :name_with_initial) do |b| b.label(class: "radio_button") { b.radio_button(class: "radio_button") } end
There are also three special methods available: object, text and value, which are the current item being rendered, its text and value methods, respectively. You can use them like this: collection_radio_buttons(:post, :author_id, Author.all, :id, :name_with_initial) do |b| b.label(:"data-value" => b.value) { b.radio_button + b.text } end
647 648 649 |
# File 'lib/action_view/helpers/form_options_helper.rb', line 647 def (object, method, collection, value_method, text_method, = {}, = {}, &block) Tags::CollectionRadioButtons.new(object, method, self, collection, value_method, text_method, , ).render(&block) end |
#collection_select(object, method, collection, value_method, text_method, options = {}, html_options = {}) ⇒ Object
Returns and tags for the collection of existing return values of
method for +object+'s class. The value returned from calling method on the instance object will
be selected. If calling method returns nil, no selection is made without including :prompt
or :include_blank in the options hash.
The :value_method and :text_method parameters are methods to be called on each member
of collection. The return values are used as the value attribute and contents of each
tag, respectively. They can also be any object that responds to call, such
as a proc, that will be called for each member of the collection to
retrieve the value/text.
Example object structure for use with this method:
class Post < ActiveRecord::Base
belongs_to :author
end
class Author < ActiveRecord::Base
has_many :posts
def name_with_initial
"#{first_name.first}. #{last_name}"
end
end
Sample usage (selecting the associated Author for an instance of Post, @post):
collection_select(:post, :author_id, Author.all, :id, :name_with_initial, prompt: true)
If @post.author_id is already 1, this would return:
201 202 203 |
# File 'lib/action_view/helpers/form_options_helper.rb', line 201 def collection_select(object, method, collection, value_method, text_method, = {}, = {}) Tags::CollectionSelect.new(object, method, self, collection, value_method, text_method, , ).render end |
#grouped_collection_select(object, method, collection, group_method, group_label_method, option_key_method, option_value_method, options = {}, html_options = {}) ⇒ Object
Returns , and tags for the collection of existing return values of
method for +object+'s class. The value returned from calling method on the instance object will
be selected. If calling method returns nil, no selection is made without including :prompt
or :include_blank in the options hash.
Parameters:
object- The instance of the class to be used for the select tagmethod- The attribute ofobjectcorresponding to the select tagcollection- An array of objects representing the tags.group_method- The name of a method which, when called on a member ofcollection, returns an array of child objects representing the tags.group_label_method- The name of a method which, when called on a member ofcollection, returns a string to be used as thelabelattribute for its tag.option_key_method- The name of a method which, when called on a child object of a member ofcollection, returns a value to be used as thevalueattribute for its tag.option_value_method- The name of a method which, when called on a child object of a member ofcollection, returns a value to be used as the contents of its tag.
Example object structure for use with this method:
class Continent < ActiveRecord::Base
has_many :countries
# attribs: id, name
end
class Country < ActiveRecord::Base
belongs_to :continent
# attribs: id, name, continent_id
end
class City < ActiveRecord::Base
belongs_to :country
# attribs: id, name, country_id
end
Sample usage:
grouped_collection_select(:city, :country_id, @continents, :countries, :name, :id, :name)
Possible output:
257 258 259 |
# File 'lib/action_view/helpers/form_options_helper.rb', line 257 def grouped_collection_select(object, method, collection, group_method, group_label_method, option_key_method, option_value_method, = {}, = {}) Tags::GroupedCollectionSelect.new(object, method, self, collection, group_method, group_label_method, option_key_method, option_value_method, , ).render end |
#grouped_options_for_select(grouped_options, selected_key = nil, options = {}) ⇒ Object
Returns a string of tags, like options_for_select, but wraps them with tags:
= [
['North America',
[['United States','US'],'Canada']],
['Europe',
['Denmark','Germany','France']]
]
()
= {
'North America' => [['United States','US'], 'Canada'],
'Europe' => ['Denmark','Germany','France']
}
()
Possible output:
Parameters:
grouped_options- Accepts a nested array or hash of strings. The first value serves as the label while the second value must be an array of options. The second value can be a nested array of text-value pairs. See options_for_select for more info. Ex. ["North America",[["United States","US"],["Canada","CA"]]]selected_key- A value equal to thevalueattribute for one of the tags, which will have theselectedattribute set. Note: It is possible for this value to match multiple options as you might have the same option in multiple groups. Each will then get selected="selected".
Options:
-
:prompt - set to true or a prompt string. When the select element doesn't have a value yet, this prepends an option with a generic prompt - "Please select" - or the given prompt string.
-
:divider - the divider for the options groups.
= [ [['United States','US'], 'Canada'], ['Denmark','Germany','France'] ] (, nil, divider: '---------')Possible output:
Note: Only the and tags are returned, so you still have to wrap the output in an appropriate tag.
524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 |
# File 'lib/action_view/helpers/form_options_helper.rb', line 524 def (, selected_key = nil, = {}) prompt = [:prompt] divider = [:divider] body = "".html_safe if prompt body.safe_concat content_tag(:option, prompt_text(prompt), value: "") end .each do |container| html_attributes = option_html_attributes(container) if divider label = divider else label, container = container end html_attributes = { label: label }.merge!(html_attributes) body.safe_concat content_tag(:optgroup, (container, selected_key), html_attributes) end body end |
#option_groups_from_collection_for_select(collection, group_method, group_label_method, option_key_method, option_value_method, selected_key = nil) ⇒ Object
Returns a string of tags, like options_from_collection_for_select, but groups them by tags based on the object relationships of the arguments.
Parameters:
collection- An array of objects representing the tags.group_method- The name of a method which, when called on a member ofcollection, returns an array of child objects representing the tags.group_label_method- The name of a method which, when called on a member ofcollection, returns a string to be used as thelabelattribute for its tag.option_key_method- The name of a method which, when called on a child object of a member ofcollection, returns a value to be used as thevalueattribute for its tag.option_value_method- The name of a method which, when called on a child object of a member ofcollection, returns a value to be used as the contents of its tag.selected_key- A value equal to thevalueattribute for one of the tags, which will have theselectedattribute set. Corresponds to the return value of one of the calls tooption_key_method. Ifnil, no selection is made. Can also be a hash if disabled values are to be specified.
Example object structure for use with this method:
class Continent < ActiveRecord::Base
has_many :countries
# attribs: id, name
end
class Country < ActiveRecord::Base
belongs_to :continent
# attribs: id, name, continent_id
end
Sample usage: option_groups_from_collection_for_select(@continents, :countries, :name, :id, :name, 3)
Possible output:
Note: Only the and tags are returned, so you still have to wrap the output in an appropriate tag.
454 455 456 457 458 459 460 461 |
# File 'lib/action_view/helpers/form_options_helper.rb', line 454 def option_groups_from_collection_for_select(collection, group_method, group_label_method, option_key_method, option_value_method, selected_key = nil) collection.map do |group| = ( group.send(group_method), option_key_method, option_value_method, selected_key) content_tag(:optgroup, , label: group.send(group_label_method)) end.join.html_safe end |
#options_for_select(container, selected = nil) ⇒ Object
Accepts a container (hash, array, enumerable, your type) and returns a string of option tags. Given a container
where the elements respond to first and last (such as a two-element array), the "lasts" serve as option values and
the "firsts" as option text. Hashes are turned into this form automatically, so the keys become "firsts" and values
become lasts. If selected is specified, the matching "last" or element will get the selected option-tag. selected
may also be an array of values to be selected when using a multiple select.
([["Dollar", "$"], ["Kroner", "DKK"]])
# => <option value="$">Dollar</option>
# => <option value="DKK">Kroner</option>
([ "VISA", "MasterCard" ], "MasterCard")
# => <option>VISA</option>
# => <option selected="selected">MasterCard</option>
({ "Basic" => "$20", "Plus" => "$40" }, "$40")
# => <option value="$20">Basic</option>
# => <option value="$40" selected="selected">Plus</option>
([ "VISA", "MasterCard", "Discover" ], ["VISA", "Discover"])
# => <option selected="selected">VISA</option>
# => <option>MasterCard</option>
# => <option selected="selected">Discover</option>
You can optionally provide HTML attributes as the last element of the array.
([ "Denmark", ["USA", {class: 'bold'}], "Sweden" ], ["USA", "Sweden"])
# => <option value="Denmark">Denmark</option>
# => <option value="USA" class="bold" selected="selected">USA</option>
# => <option value="Sweden" selected="selected">Sweden</option>
([["Dollar", "$", {class: "bold"}], ["Kroner", "DKK", {onclick: "alert('HI');"}]])
# => <option value="$" class="bold">Dollar</option>
# => <option value="DKK" onclick="alert('HI');">Kroner</option>
If you wish to specify disabled option tags, set selected to be a hash, with :disabled being either a value
or array of values to be disabled. In this case, you can use :selected to specify selected option tags.
(["Free", "Basic", "Advanced", "Super Platinum"], disabled: "Super Platinum")
# => <option value="Free">Free</option>
# => <option value="Basic">Basic</option>
# => <option value="Advanced">Advanced</option>
# => <option value="Super Platinum" disabled="disabled">Super Platinum</option>
(["Free", "Basic", "Advanced", "Super Platinum"], disabled: ["Advanced", "Super Platinum"])
# => <option value="Free">Free</option>
# => <option value="Basic">Basic</option>
# => <option value="Advanced" disabled="disabled">Advanced</option>
# => <option value="Super Platinum" disabled="disabled">Super Platinum</option>
(["Free", "Basic", "Advanced", "Super Platinum"], selected: "Free", disabled: "Super Platinum")
# => <option value="Free" selected="selected">Free</option>
# => <option value="Basic">Basic</option>
# => <option value="Advanced">Advanced</option>
# => <option value="Super Platinum" disabled="disabled">Super Platinum</option>
NOTE: Only the option tags are returned, you have to wrap this call in a regular HTML select tag.
350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 |
# File 'lib/action_view/helpers/form_options_helper.rb', line 350 def (container, selected = nil) return container if String === container selected, disabled = extract_selected_and_disabled(selected).map do |r| Array(r).map { |item| item.to_s } end container.map do |element| html_attributes = option_html_attributes(element) text, value = option_text_and_value(element).map { |item| item.to_s } html_attributes[:selected] ||= option_value_selected?(value, selected) html_attributes[:disabled] ||= disabled && option_value_selected?(value, disabled) html_attributes[:value] = value content_tag_string(:option, text, html_attributes) end.join("\n").html_safe end |
#options_from_collection_for_select(collection, value_method, text_method, selected = nil) ⇒ Object
Returns a string of option tags that have been compiled by iterating over the collection and assigning
the result of a call to the value_method as the option value and the text_method as the option text.
(@people, 'id', 'name')
# => <option value="#{person.id}">#{person.name}</option>
This is more often than not used inside a #select_tag like this example:
select_tag 'person', (@people, 'id', 'name')
If selected is specified as a value or array of values, the element(s) returning a match on value_method
will be selected option tag(s).
If selected is specified as a Proc, those members of the collection that return true for the anonymous
function are the selected values.
selected can also be a hash, specifying both :selected and/or :disabled values as required.
Be sure to specify the same class as the value_method when specifying selected or disabled options.
Failure to do this will produce undesired results. Example:
options_from_collection_for_select(@people, 'id', 'name', '1')
Will not select a person with the id of 1 because 1 (an Integer) is not the same as '1' (a string)
options_from_collection_for_select(@people, 'id', 'name', 1)
should produce the desired results.
393 394 395 396 397 398 399 400 401 402 403 404 |
# File 'lib/action_view/helpers/form_options_helper.rb', line 393 def (collection, value_method, text_method, selected = nil) = collection.map do |element| [value_for_collection(element, text_method), value_for_collection(element, value_method), option_html_attributes(element)] end selected, disabled = extract_selected_and_disabled(selected) select_deselect = { selected: extract_values_from_collection(collection, value_method, selected), disabled: extract_values_from_collection(collection, value_method, disabled) } (, select_deselect) end |
#select(object, method, choices = nil, options = {}, html_options = {}, &block) ⇒ Object
Create a select tag and a series of contained option tags for the provided object and method. The option currently held by the object will be selected, provided that the object is available.
There are two possible formats for the choices parameter, corresponding to other helpers' output:
-
A flat collection (see
options_for_select). -
A nested collection (see
grouped_options_for_select).
For example:
select("post", "person_id", Person.all.collect {|p| [ p.name, p.id ] }, { include_blank: true })
would become:
assuming the associated person has ID 1.
This can be used to provide a default set of options in the standard way: before rendering the create form, a new model instance is assigned the default options and bound to @model_name. Usually this model is not saved to the database. Instead, a second model object is created when the create request is received. This allows the user to submit a form page more than once with the expected results of creating multiple records. In addition, this allows a single partial to be used to generate form inputs for both edit and create forms.
By default, post.person_id is the selected option. Specify selected: value to use a different selection or selected: nil to leave all options unselected. Similarly, you can specify values to be disabled in the option tags by specifying the :disabled option. This can either be a single value or an array of values to be disabled.
A block can be passed to select to customize how the options tags will be rendered. This
is useful when the options tag has complex attributes.
select(report, "campaign_ids") do
available_campaigns.each do |c|
content_tag(:option, c.name, value: c.id, data: { tags: c..to_json })
end
end
Gotcha
The HTML specification says when multiple parameter passed to select and all options got deselected
web browsers do not send any value to server. Unfortunately this introduces a gotcha:
if an User model has many roles and have role_ids accessor, and in the form that edits roles of the user
the user deselects all roles from role_ids multiple select box, no role_ids parameter is sent. So,
any mass-assignment idiom like
@user.update(params[:user])
wouldn't update roles.
To prevent this the helper generates an auxiliary hidden field before every multiple select. The hidden field has the same name as multiple select and blank value.
Note: The client either sends only the hidden field (representing the deselected multiple select box), or both fields. This means that the resulting array always contains a blank string.
In case if you don't want the helper to generate this hidden field you can specify include_hidden: false option.
162 163 164 |
# File 'lib/action_view/helpers/form_options_helper.rb', line 162 def select(object, method, choices = nil, = {}, = {}, &block) Tags::Select.new(object, method, self, choices, , , &block).render end |
#time_zone_options_for_select(selected = nil, priority_zones = nil, model = ::ActiveSupport::TimeZone) ⇒ Object
Returns a string of option tags for pretty much any time zone in the
world. Supply a ActiveSupport::TimeZone name as selected to have it
marked as the selected option tag. You can also supply an array of
ActiveSupport::TimeZone objects as priority_zones, so that they will
be listed above the rest of the (long) list. (You can use
ActiveSupport::TimeZone.us_zones as a convenience for obtaining a list
of the US time zones, or a Regexp to select the zones of your choice)
The selected parameter must be either nil, or a string that names
a ActiveSupport::TimeZone.
By default, model is the ActiveSupport::TimeZone constant (which can
be obtained in Active Record as a value object). The only requirement
is that the model parameter be an object that responds to all, and
returns an array of objects that represent time zones.
NOTE: Only the option tags are returned, you have to wrap this call in a regular HTML select tag.
568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 |
# File 'lib/action_view/helpers/form_options_helper.rb', line 568 def (selected = nil, priority_zones = nil, model = ::ActiveSupport::TimeZone) = "".html_safe zones = model.all convert_zones = lambda { |list| list.map { |z| [ z.to_s, z.name ] } } if priority_zones if priority_zones.is_a?(Regexp) priority_zones = zones.select { |z| z =~ priority_zones } end .safe_concat (convert_zones[priority_zones], selected) .safe_concat content_tag(:option, '-------------', value: '', disabled: true) .safe_concat "\n" zones = zones - priority_zones end .safe_concat (convert_zones[zones], selected) end |
#time_zone_select(object, method, priority_zones = nil, options = {}, html_options = {}) ⇒ Object
Returns select and option tags for the given object and method, using #time_zone_options_for_select to generate the list of option tags.
In addition to the :include_blank option documented above,
this method also supports a :model option, which defaults
to ActiveSupport::TimeZone. This may be used by users to specify a
different time zone model object. (See time_zone_options_for_select
for more information.)
You can also supply an array of ActiveSupport::TimeZone objects
as priority_zones, so that they will be listed above the rest of the
(long) list. (You can use ActiveSupport::TimeZone.us_zones as a convenience
for obtaining a list of the US time zones, or a Regexp to select the zones
of your choice)
Finally, this method supports a :default option, which selects
a default ActiveSupport::TimeZone if the object's time zone is nil.
time_zone_select( "user", "time_zone", nil, include_blank: true)
time_zone_select( "user", "time_zone", nil, default: "Pacific Time (US & Canada)" )
time_zone_select( "user", 'time_zone', ActiveSupport::TimeZone.us_zones, default: "Pacific Time (US & Canada)")
time_zone_select( "user", 'time_zone', [ ActiveSupport::TimeZone['Alaska'], ActiveSupport::TimeZone['Hawaii'] ])
time_zone_select( "user", 'time_zone', /Australia/)
time_zone_select( "user", "time_zone", ActiveSupport::TimeZone.all.sort, model: ActiveSupport::TimeZone)
290 291 292 |
# File 'lib/action_view/helpers/form_options_helper.rb', line 290 def time_zone_select(object, method, priority_zones = nil, = {}, = {}) Tags::TimeZoneSelect.new(object, method, self, priority_zones, , ).render end |